var init = (function () {
  'use strict';

  var Gvc1_0 = imports.gi.Gvc;

  var St1_0 = imports.gi.St;

  // https://gitlab.gnome.org/GNOME/gnome-shell/-/blob/master/js/ui/status/volume.js
  const Volume = imports.ui.status.volume;
  var ApplicationStreamSlider = class extends Volume.StreamSlider {
      constructor(stream) {
          super(Volume.getMixerControl());
          this.stream = stream;
          this._icon.icon_name = stream.get_icon_name();
          if (stream.get_name()) {
              this._vbox = new St1_0.BoxLayout({ vertical: true });
              this._label = new St1_0.Label({ text: stream.get_name() });
              this._vbox.add(this._label);
              this.item.remove_child(this._slider);
              this._vbox.add(this._slider);
              this._slider.set_height(32);
              this.item.actor.add(this._vbox);
          }
      }
  };

  // https://gitlab.gnome.org/GNOME/gnome-shell/-/blob/master/js/ui/popupMenu.js
  const PopupMenu = imports.ui.popupMenu;
  // https://gitlab.gnome.org/GNOME/gnome-shell/-/blob/master/js/ui/status/volume.js
  const Volume$1 = imports.ui.status.volume;
  class VolumeMixerPopupMenuClass extends PopupMenu.PopupMenuSection {
      constructor() {
          super();
          this._applicationStreams = {};
          // The PopupSeparatorMenuItem needs something above and below it or it won't display
          this._hiddenItem = new PopupMenu.PopupBaseMenuItem();
          this._hiddenItem.set_height(0);
          this.addMenuItem(this._hiddenItem);
          this.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
          this._control = Volume$1.getMixerControl();
          this._control.connect("stream-added", this._streamAdded.bind(this));
          this._control.connect("stream-removed", this._streamRemoved.bind(this));
          for (const stream of this._control.get_streams()) {
              this._streamAdded(this._control, stream.get_id());
          }
      }
      _streamAdded(control, id) {
          if (id in this._applicationStreams) {
              return;
          }
          const stream = control.lookup_stream_id(id);
          if (stream.is_event_stream) {
              return;
          }
          if (!(stream instanceof Gvc1_0.MixerSinkInput)) {
              return;
          }
          this._applicationStreams[id] = new ApplicationStreamSlider(stream);
          this.addMenuItem(this._applicationStreams[id].item);
      }
      _streamRemoved(_control, id) {
          if (id in this._applicationStreams) {
              this._applicationStreams[id].item.destroy();
              delete this._applicationStreams[id];
          }
      }
  }
  var VolumeMixerPopupMenu = VolumeMixerPopupMenuClass;

  const Main = imports.ui.main;
  var volumeMixer = null;
  function enable() {
      volumeMixer = new VolumeMixerPopupMenu();
      Main.panel.statusArea.aggregateMenu._volume.menu.addMenuItem(volumeMixer);
  }
  function disable() {
      // REMINDER: It's required for extensions to clean up after themselves when
      // they are disabled. This is required for approval during review!
      if (volumeMixer !== null) {
          volumeMixer.destroy();
          volumeMixer = null;
      }
  }
  function extension () {
      return {
          enable,
          disable
      };
  }

  return extension;

}());
